# eric7.Network.IRC

Package containing the IRC support.

### Modules

IrcChannelEditDialog | Module implementing a dialog to edit channel data.
IrcChannelWidget | Module implementing the IRC channel widget.
IrcIdentitiesEditDialog | Module implementing the identities management dialog.
IrcMessageEdit | Module implementing a specialized line edit for entering IRC messages.
IrcNetworkEditDialog | Module implementing a dialog for editing IRC network definitions.
IrcNetworkListDialog | Module implementing a dialog to list the configured IRC networks.
IrcNetworkManager | Module implementing the IRC data structures and their manager.
IrcNetworkWidget | Module implementing the network part of the IRC widget.
IrcServerEditDialog | Module implementing a dialog for editing the IRC server configuration.
IrcUtilities | Module implementing functions used by several IRC objects.
IrcWidget | Module implementing the IRC window.